import { useEffect, useState } from 'react';

const CustomToast = ({ message, type = 'success' }) => {
    const [visible, setVisible] = useState(false);
    const [progress, setProgress] = useState(100); // Inicializa com 100%

    useEffect(() => {
        setVisible(true);

        const progressInterval = setInterval(() => {
            setProgress((prev) => (prev > 0 ? prev - 1 : 0));
        }, 60); // Reduzindo progressivamente

        const timer = setTimeout(() => {
            setVisible(false);
            setProgress(100); // Reseta o progresso quando o toast some
        }, 6000);

        return () => {
            clearTimeout(timer);
            clearInterval(progressInterval);
        };
    }, []);

    const toastStyles = {
        success: 'bg-primary',
        error: 'bg-danger',
    };

    return (
        <div
            className={`fixed bottom-3 left-1/2 w-full transform -translate-x-1/2 max-w-xs text-text-white rounded-full shadow-lg transition-opacity duration-1000 ${visible ? 'opacity-100' : 'opacity-0'
                } ${toastStyles[type]}`}
        >
            <div className="flex justify-between items-center px-3 py-1 relative">
                <span className="text-[.75rem] flex items-center justify-center w-full">
                    {type === 'success' ? (
                        <i className="bi bi-check2-circle me-2 text-2xl animate-pulse"></i>
                    ) : (
                        <i className="bi bi-exclamation-circle me-2 text-2xl animate-pulse"></i>
                    )}
                    {message}
                </span>
            </div>
            {/* Barra de progresso */}
            <div className="absolute bottom-0 left-0 w-full h-1 bg-gray-300">
                <div
                    className="h-full bg-white transition-all"
                    style={{ width: `${progress}%` }}
                ></div>
            </div>
        </div>
    );
};

export default CustomToast;
